@@ -1,19 +1,9 @@
 /*
- *   Copyright 2013 Martin Gräßlin <mgraesslin@kde.org>
- *
- *   This library is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU Lesser General Public
- *   License as published by the Free Software Foundation; either
- *   version 2.1 of the License, or (at your option) any later version.
- *
- *   This library is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- *   Lesser General Public License for more details.
- *
- *   You should have received a copy of the GNU Lesser General Public
- *   License along with this library.  If not, see <http://www.gnu.org/licenses/>.
- */
+    SPDX-FileCopyrightText: 2013 Martin Gräßlin <mgraesslin@kde.org>
+
+    SPDX-License-Identifier: LGPL-2.1-or-later
+*/
+
 #include "nettesthelper.h"
 #include <netwm.h>
 #include <qtest_widgets.h>
@@ -62,15 +52,18 @@ private Q_SLOTS:
     void testUserTime();
     void testStartupId();
     void testDesktopFileName();
+    void testAppMenuObjectPath();
+    void testAppMenuServiceName();
     void testHandledIcons_data();
     void testHandledIcons();
     void testPid();
     void testName();
     void testIconName();
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 0)
     void testStrut();
+#endif
     void testExtendedStrut();
     void testIconGeometry();
-    void testFullscreenMonitors();
     void testWindowType_data();
     void testWindowType();
 
@@ -110,7 +103,6 @@ private:
 
 void NetWinInfoTestClient::initTestCase()
 {
-    qsrand(QDateTime::currentMSecsSinceEpoch());
 }
 
 void NetWinInfoTestClient::cleanupTestCase()
@@ -286,6 +278,36 @@ void NetWinInfoTestClient::testStartupId()
     QCOMPARE(info.startupId(), "foo");
 }
 
+void NetWinInfoTestClient::testAppMenuObjectPath()
+{
+    ATOM(_KDE_NET_WM_APPMENU_OBJECT_PATH)
+    INFO
+
+    QVERIFY(!info.appMenuObjectPath());
+
+    xcb_change_property(connection(), XCB_PROP_MODE_REPLACE, m_testWindow,
+                        atom, XCB_ATOM_STRING, 8, 3, "foo");
+    xcb_flush(connection());
+
+    waitForPropertyChange(&info, atom, NET::Property(0), NET::WM2AppMenuObjectPath);
+    QCOMPARE(info.appMenuObjectPath(), "foo");
+}
+
+void NetWinInfoTestClient::testAppMenuServiceName()
+{
+    ATOM(_KDE_NET_WM_APPMENU_SERVICE_NAME)
+    INFO
+
+    QVERIFY(!info.appMenuServiceName());
+
+    xcb_change_property(connection(), XCB_PROP_MODE_REPLACE, m_testWindow,
+                        atom, XCB_ATOM_STRING, 8, 3, "foo");
+    xcb_flush(connection());
+
+    waitForPropertyChange(&info, atom, NET::Property(0), NET::WM2AppMenuServiceName);
+    QCOMPARE(info.appMenuServiceName(), "foo");
+}
+
 void NetWinInfoTestClient::testDesktopFileName()
 {
     QVERIFY(connection());
@@ -345,17 +367,17 @@ void NetWinInfoTestClient::testPid()
     INFO
 
     QCOMPARE(info.pid(), 0);
-    info.setPid(m_xvfb->pid());
-    QCOMPARE(info.pid(), m_xvfb->pid());
+    info.setPid(m_xvfb->processId());
+    QCOMPARE(info.pid(), m_xvfb->processId());
 
     // compare with the X property
     QVERIFY(atom != XCB_ATOM_NONE);
     GETPROP(XCB_ATOM_CARDINAL, 1, 32)
-    QCOMPARE(reinterpret_cast<uint32_t *>(xcb_get_property_value(reply.data()))[0], uint32_t(m_xvfb->pid()));
+    QCOMPARE(reinterpret_cast<uint32_t *>(xcb_get_property_value(reply.data()))[0], uint32_t(m_xvfb->processId()));
 
     // and wait for our event
     waitForPropertyChange(&info, atom, NET::WMPid);
-    QCOMPARE(info.pid(), m_xvfb->pid());
+    QCOMPARE(info.pid(), m_xvfb->processId());
 }
 
 void NetWinInfoTestClient::performNameTest(xcb_atom_t atom, const char *(NETWinInfo:: *getter)(void)const, void (NETWinInfo:: *setter)(const char *), NET::Property property)
@@ -408,6 +430,7 @@ void NetWinInfoTestClient::testName()
     performNameTest(atom, &NETWinInfo::name, &NETWinInfo::setName, NET::WMName);
 }
 
+#if KWINDOWSYSTEM_ENABLE_DEPRECATED_SINCE(5, 0)
 void NetWinInfoTestClient::testStrut()
 {
     QVERIFY(connection());
@@ -449,6 +472,7 @@ void NetWinInfoTestClient::testStrut()
     QCOMPARE(extents.right,  newExtents.right);
     QCOMPARE(extents.top,    newExtents.top);
 }
+#endif
 
 void NetWinInfoTestClient::testExtendedStrut()
 {
@@ -574,49 +598,6 @@ void NetWinInfoTestClient::testIconGeometry()
     QCOMPARE(geo.size.height, newGeo.size.height);
 }
 
-void NetWinInfoTestClient::testFullscreenMonitors()
-{
-    QVERIFY(connection());
-    ATOM(_NET_WM_FULLSCREEN_MONITORS)
-    INFO
-
-    NETFullscreenMonitors topology = info.fullscreenMonitors();
-    QCOMPARE(topology.bottom, 0);
-    QCOMPARE(topology.left, 0);
-    QCOMPARE(topology.right, 0);
-    QCOMPARE(topology.top, -1);
-
-    NETFullscreenMonitors newTopology;
-    newTopology.bottom = 10;
-    newTopology.left   = 20;
-    newTopology.right  = 30;
-    newTopology.top    = 40;
-    info.setFullscreenMonitors(newTopology);
-    topology = info.fullscreenMonitors();
-    QCOMPARE(topology.bottom, newTopology.bottom);
-    QCOMPARE(topology.left,   newTopology.left);
-    QCOMPARE(topology.right,  newTopology.right);
-    QCOMPARE(topology.top,    newTopology.top);
-
-    // compare with the X property
-    QVERIFY(atom != XCB_ATOM_NONE);
-    GETPROP(XCB_ATOM_CARDINAL, 4, 32)
-    uint32_t *data = reinterpret_cast<uint32_t *>(xcb_get_property_value(reply.data()));
-    QCOMPARE(data[0], uint32_t(newTopology.top));
-    QCOMPARE(data[1], uint32_t(newTopology.bottom));
-    QCOMPARE(data[2], uint32_t(newTopology.left));
-    QCOMPARE(data[3], uint32_t(newTopology.right));
-
-    // and wait for our event
-    QEXPECT_FAIL("", "FullscreenMonitors not handled in events", Continue);
-    waitForPropertyChange(&info, atom, NET::Property(0), NET::WM2FullscreenMonitors);
-    topology = info.fullscreenMonitors();
-    QCOMPARE(topology.bottom, newTopology.bottom);
-    QCOMPARE(topology.left,   newTopology.left);
-    QCOMPARE(topology.right,  newTopology.right);
-    QCOMPARE(topology.top,    newTopology.top);
-}
-
 Q_DECLARE_METATYPE(NET::WindowType)
 void NetWinInfoTestClient::testWindowType_data()
 {
@@ -641,10 +622,11 @@ void NetWinInfoTestClient::testWindowType_data()
     QTest::newRow("Dock")         << NET::Dock         << 1 << QByteArrayLiteral("_NET_WM_WINDOW_TYPE_DOCK")     << QByteArray();
     QTest::newRow("Desktop")      << NET::Desktop      << 1 << QByteArrayLiteral("_NET_WM_WINDOW_TYPE_DESKTOP")  << QByteArray();
     QTest::newRow("Tooltip")      << NET::Tooltip      << 1 << QByteArrayLiteral("_NET_WM_WINDOW_TYPE_TOOLTIP")  << QByteArray();
-    QTest::newRow("ComboBox")     << NET::ComboBox     << 1 << QByteArrayLiteral("_NET_WM_WINDOW_TYPE_COMBOBOX") << QByteArray();
+    QTest::newRow("ComboBox")     << NET::ComboBox     << 1 << QByteArrayLiteral("_NET_WM_WINDOW_TYPE_COMBO")    << QByteArray();
     QTest::newRow("DNDIcon")      << NET::DNDIcon      << 1 << QByteArrayLiteral("_NET_WM_WINDOW_TYPE_DND")      << QByteArray();
     QTest::newRow("Normal")       << NET::Normal       << 1 << QByteArrayLiteral("_NET_WM_WINDOW_TYPE_NORMAL")   << QByteArray();
     QTest::newRow("OnScreenDisplay") << NET::OnScreenDisplay << 1 << QByteArrayLiteral("_KDE_NET_WM_WINDOW_TYPE_ON_SCREEN_DISPLAY") << QByteArray();
+    QTest::newRow("CriticalNotification") << NET::CriticalNotification << 1 << QByteArrayLiteral("_KDE_NET_WM_WINDOW_TYPE_CRITICAL_NOTIFICATION") << QByteArray();
 }
 
 void NetWinInfoTestClient::testWindowType()
