@@ -1,39 +1,20 @@
-/****************************************************************************
+/*
+    SPDX-FileCopyrightText: 2001-2003 Lubos Lunak <l.lunak@kde.org>
+    SPDX-FileCopyrightText: 2012 David Faure <faure@kde.org>
 
- Copyright (C) 2001-2003 Lubos Lunak        <l.lunak@kde.org>
- Copyright 2012 David Faure <faure@kde.org>
-
-Permission is hereby granted, free of charge, to any person obtaining a
-copy of this software and associated documentation files (the "Software"),
-to deal in the Software without restriction, including without limitation
-the rights to use, copy, modify, merge, publish, distribute, sublicense,
-and/or sell copies of the Software, and to permit persons to whom the
-Software is furnished to do so, subject to the following conditions:
-
-The above copyright notice and this permission notice shall be included in
-all copies or substantial portions of the Software.
-
-THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
-IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
-FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT.  IN NO EVENT SHALL
-THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
-LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
-FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
-DEALINGS IN THE SOFTWARE.
-
-****************************************************************************/
+    SPDX-License-Identifier: MIT
+*/
 
 #include "kxmessages.h"
 #include "kxutils_p.h"
 
 #if KWINDOWSYSTEM_HAVE_X11
 
-#include <qcoreapplication.h>
+#include <QCoreApplication>
 #include <QDebug>
-#include <QWidget> // WId
+#include <QWindow> // WId
 #include <QAbstractNativeEventFilter>
 
-#include <xcb/xcb.h>
 #include <qx11info_x11.h>
 #include <X11/Xlib.h>
 
@@ -112,7 +93,7 @@ public:
     KXMessagesPrivate(KXMessages *parent, const char *acceptBroadcast, xcb_connection_t *c, xcb_window_t root)
         : accept_atom1(acceptBroadcast ? QByteArray(acceptBroadcast) + QByteArrayLiteral("_BEGIN") : QByteArray())
         , accept_atom2(acceptBroadcast ? QByteArray(acceptBroadcast) : QByteArray())
-        , handle(new QWidget)
+        , handle(new QWindow)
         , q(parent)
         , valid(c)
         , connection(c)
@@ -129,13 +110,13 @@ public:
     XcbAtom accept_atom1;
     XcbAtom accept_atom2;
     QMap< WId, QByteArray > incoming_messages;
-    QScopedPointer<QWidget> handle;
+    QScopedPointer<QWindow> handle;
     KXMessages *q;
     bool valid;
     xcb_connection_t *connection;
     xcb_window_t rootWindow;
 
-    bool nativeEventFilter(const QByteArray &eventType, void *message, long *result) Q_DECL_OVERRIDE
+    bool nativeEventFilter(const QByteArray &eventType, void *message, long *result) override
     {
         Q_UNUSED(result);
 	// A faster comparison than eventType != "xcb_generic_event_t"
@@ -179,7 +160,7 @@ public:
     }
 };
 
-#ifndef KWINDOWSYSTEM_NO_DEPRECATED
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 18)
 static void send_message_internal(WId w_P, const QString &msg_P, long mask_P,
                                   Display *disp, Atom atom1_P, Atom atom2_P, Window handle_P);
 // for broadcasting
@@ -233,7 +214,7 @@ void KXMessages::broadcastMessage(const char *msg_type_P, const QString &message
                           a1, a2, d->handle->winId());
 }
 
-#ifndef KWINDOWSYSTEM_NO_DEPRECATED
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 18)
 bool KXMessages::broadcastMessageX(Display *disp, const char *msg_type_P,
                                    const QString &message_P, int screen_P)
 {
@@ -285,7 +266,7 @@ void KXMessages::sendMessage(WId w_P, const char *msg_type_P, const QString &mes
 bool KXMessages::sendMessageX(Display *disp, WId w_P, const char *msg_type_P,
                               const QString &message_P)
 {
-    if (disp == NULL) {
+    if (disp == nullptr) {
         return false;
     }
     Atom a2 = XInternAtom(disp, msg_type_P, false);
@@ -299,7 +280,7 @@ bool KXMessages::sendMessageX(Display *disp, WId w_P, const char *msg_type_P,
 }
 #endif
 
-#ifndef KWINDOWSYSTEM_NO_DEPRECATED
+#if KWINDOWSYSTEM_BUILD_DEPRECATED_SINCE(5, 18)
 static void send_message_internal(WId w_P, const QString &msg_P, long mask_P,
                                   Display *disp, Atom atom1_P, Atom atom2_P, Window handle_P)
 {
